@@ -120,7 +120,11 @@ def load_dependencies(
                 # TODO check if repo class is subclass of AuthenticationRepository
                 # or will that get caught by except
                 contained_auth_repo = auth_class(
-                    library_dir, name, urls, out_of_band_authentication, custom
+                    library_dir=library_dir,
+                    name=name,
+                    urls=urls,
+                    out_of_band_authentication=out_of_band_authentication,
+                    custom=custom,
                 )
             except Exception as e:
                 taf_logger.error(
@@ -138,6 +142,14 @@ def load_dependencies(
             ", ".join(dependencies_dict.keys()),
         )
 
+    # we don't need to set auth_repo dependencies for each commit,
+    # just the latest version
+    latest_commit = commits[-1]
+    dependencies = _load_dependencies_json(auth_repo, latest_commit)
+    auth_repo.dependencies = (
+        dependencies["dependencies"] if dependencies is not None else {}
+    )
+
 
 def load_repositories(
     auth_repo,
@@ -147,6 +159,7 @@ def load_repositories(
     only_load_targets=True,
     commits=None,
     roles=None,
+    default_branch="main",
 ):
     """
     Creates target repositories by reading repositories.json and targets.json files
@@ -225,16 +238,20 @@ def load_repositories(
             urls = _get_urls(mirrors, name, repo_data)
             if name not in targets and only_load_targets:
                 continue
-
             custom = _get_custom_data(repo_data, targets.get(name))
+            allow_unsafe = False
 
             git_repo = None
             try:
                 if factory is not None:
-                    git_repo = factory(library_dir, name, urls, custom)
+                    git_repo = factory(
+                        library_dir, name, urls, custom, default_branch, allow_unsafe
+                    )
                 else:
                     git_repo_class = _determine_repo_class(repo_classes, name)
-                    git_repo = git_repo_class(library_dir, name, urls, custom)
+                    git_repo = git_repo_class(
+                        library_dir, name, urls, custom, default_branch, allow_unsafe
+                    )
             except Exception as e:
                 taf_logger.error(
                     "Auth repo {}: an error occurred while instantiating repository {}: {}",
@@ -358,14 +375,14 @@ def get_repositories_paths_by_custom_data(auth_repo, commit=None, **custom):
 
 
 def get_deduplicated_auth_repositories(auth_repo, commits):
-    return _get_deduplicated_target_or_auth_repositotries(auth_repo, commits, True)
+    return _get_deduplicated_target_or_auth_repositories(auth_repo, commits, True)
 
 
 def get_deduplicated_repositories(auth_repo, commits):
-    return _get_deduplicated_target_or_auth_repositotries(auth_repo, commits)
+    return _get_deduplicated_target_or_auth_repositories(auth_repo, commits)
 
 
-def _get_deduplicated_target_or_auth_repositotries(auth_repo, commits, load_auth=False):
+def _get_deduplicated_target_or_auth_repositories(auth_repo, commits, load_auth=False):
     loaded_repositories_dict = _dependencies_dict if load_auth else _repositories_dict
     auth_msg = "included authentication " if load_auth else ""
     repositories_msg = (
@@ -524,15 +541,13 @@ def get_repo_urls(auth_repo, repo_name, commit=None):
         return _get_urls(mirrors, repo_name)
 
 
-def _load_dependencies_json(auth_repo, commit):
+def _load_dependencies_json(auth_repo, commit=None):
     try:
         return _get_json_file(auth_repo, DEPENDENCIES_JSON_PATH, commit)
     except InvalidOrMissingMetadataError as e:
         if f"{DEPENDENCIES_JSON_PATH} not available at revision" in str(e):
             taf_logger.debug("Skipping commit {} due to: {}", commit, str(e))
-            return None
-        else:
-            raise
+        return None
 
 
 def _load_hosts_json(auth_repo, commit=None):
